@@ -7,7 +7,7 @@
 
 #include "mediaplayer2player.h"
 
-#include "mpris2logging.h"
+#include "mpris2_logging.h"
 #include "videocontroller.h"
 
 #include <QCryptographicHash>
@@ -24,7 +24,7 @@ MediaPlayer2Player::MediaPlayer2Player(VideoController *audioPlayer, QObject *pa
     , mProgressIndicatorSignal(
           QDBusMessage::createSignal(QStringLiteral("/org/kde/kmediasession"), QStringLiteral("com.canonical.Unity.LauncherEntry"), QStringLiteral("Update")))
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::MediaPlayer2Player()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::MediaPlayer2Player()";
 
     connect(m_audioPlayer, &VideoController::currentVideoChanged, this, &MediaPlayer2Player::setSource);
     connect(m_audioPlayer, &VideoController::currentVideoChanged, this, &MediaPlayer2Player::playerMetaDataChanged);
@@ -41,12 +41,12 @@ MediaPlayer2Player::MediaPlayer2Player(VideoController *audioPlayer, QObject *pa
 
 MediaPlayer2Player::~MediaPlayer2Player()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::~MediaPlayer2Player()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::~MediaPlayer2Player()";
 }
 
 QString MediaPlayer2Player::PlaybackStatus() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::PlaybackStatus()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::PlaybackStatus()";
     QString result;
 
     if (!m_audioPlayer->hasVideo()) {
@@ -66,7 +66,7 @@ QString MediaPlayer2Player::PlaybackStatus() const
 
 bool MediaPlayer2Player::CanGoNext() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanGoNext()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanGoNext()";
     if (m_audioPlayer) {
         return m_audioPlayer->videoQueue()->canGoNext();
     } else {
@@ -76,13 +76,13 @@ bool MediaPlayer2Player::CanGoNext() const
 
 void MediaPlayer2Player::Next()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Next()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Next()";
     m_audioPlayer->next();
 }
 
 bool MediaPlayer2Player::CanGoPrevious() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanGoPrevious()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanGoPrevious()";
     if (m_audioPlayer) {
         return m_audioPlayer->videoQueue()->canGoPrevious();
     } else {
@@ -92,57 +92,57 @@ bool MediaPlayer2Player::CanGoPrevious() const
 
 void MediaPlayer2Player::Previous()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Previous()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Previous()";
     m_audioPlayer->previous();
 }
 
 bool MediaPlayer2Player::CanPause() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanPause()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanPause()";
     return true;
 }
 
 void MediaPlayer2Player::Pause()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Pause()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Pause()";
     if (m_audioPlayer)
         m_audioPlayer->pause();
 }
 
 void MediaPlayer2Player::PlayPause()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::PlayPause()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::PlayPause()";
     m_audioPlayer->togglePlaying();
 }
 
 void MediaPlayer2Player::Stop()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Stop()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Stop()";
     m_audioPlayer->stop();
 }
 
 bool MediaPlayer2Player::CanPlay() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanPlay()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanPlay()";
     return true;
 }
 
 void MediaPlayer2Player::Play()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Play()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Play()";
     if (m_audioPlayer)
         m_audioPlayer->play();
 }
 
 double MediaPlayer2Player::Volume() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Volume()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Volume()";
     return m_volume;
 }
 
 void MediaPlayer2Player::setVolume(double volume)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::setVolume(" << volume << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::setVolume(" << volume << ")";
     if (m_audioPlayer) {
         m_volume = qBound(0.0, volume, 1.0);
         Q_EMIT volumeChanged(m_volume);
@@ -155,13 +155,13 @@ void MediaPlayer2Player::setVolume(double volume)
 
 QVariantMap MediaPlayer2Player::Metadata() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Metadata()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Metadata()";
     return m_metadata;
 }
 
 qlonglong MediaPlayer2Player::Position() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Position()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Position()";
     if (m_audioPlayer->hasVideo()) {
         return qlonglong(m_audioPlayer->position()) * 1000000;
     } else {
@@ -171,25 +171,25 @@ qlonglong MediaPlayer2Player::Position() const
 
 double MediaPlayer2Player::Rate() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Rate()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Rate()";
     return 1.0;
 }
 
 double MediaPlayer2Player::MinimumRate() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::MinimumRate()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::MinimumRate()";
     return 1.0;
 }
 
 double MediaPlayer2Player::MaximumRate() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::MaximumRate()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::MaximumRate()";
     return 1.0;
 }
 
 void MediaPlayer2Player::setRate(double newRate)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::setRate(" << newRate << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::setRate(" << newRate << ")";
     if (newRate <= 0.0001 && newRate >= -0.0001) {
         Pause();
     }
@@ -197,19 +197,19 @@ void MediaPlayer2Player::setRate(double newRate)
 
 bool MediaPlayer2Player::CanSeek() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanSeek()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanSeek()";
     return true;
 }
 
 bool MediaPlayer2Player::CanControl() const
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::CanControl()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::CanControl()";
     return true;
 }
 
 void MediaPlayer2Player::Seek(qlonglong Offset)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::Seek(" << Offset << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::Seek(" << Offset << ")";
     if (m_audioPlayer) {
         auto offset = (m_position + Offset) / 1000000;
         m_audioPlayer->setPosition(int(offset));
@@ -218,7 +218,7 @@ void MediaPlayer2Player::Seek(qlonglong Offset)
 
 void MediaPlayer2Player::SetPosition(const QDBusObjectPath &trackId, qlonglong pos)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::SetPosition(" << pos << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::SetPosition(" << pos << ")";
     if (m_audioPlayer) {
         if (m_audioPlayer->currentVideo() != nullptr) {
             if (trackId.path() == m_currentTrackId) {
@@ -230,33 +230,33 @@ void MediaPlayer2Player::SetPosition(const QDBusObjectPath &trackId, qlonglong p
 
 void MediaPlayer2Player::OpenUri(const QString &uri)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::OpenUri(" << uri << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::OpenUri(" << uri << ")";
     Q_UNUSED(uri)
 }
 
 void MediaPlayer2Player::playerPlaybackStateChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerPlaybackStateChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerPlaybackStateChanged()";
     signalPropertiesChange(QStringLiteral("PlaybackStatus"), PlaybackStatus());
     Q_EMIT playbackStatusChanged();
 }
 
 void MediaPlayer2Player::playerPlaybackRateChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerPlaybackRateChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerPlaybackRateChanged()";
     signalPropertiesChange(QStringLiteral("Rate"), Rate());
     Q_EMIT rateChanged(Rate());
 }
 
 void MediaPlayer2Player::playerSeeked(qint64 position)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerSeeked(" << position << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerSeeked(" << position << ")";
     Q_EMIT Seeked(position * 1000000);
 }
 
 void MediaPlayer2Player::audioPositionChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::audioPositionChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::audioPositionChanged()";
     // for progress indicator on taskbar
     if (m_audioPlayer)
         setPropertyPosition(static_cast<int>(m_audioPlayer->position()));
@@ -274,12 +274,12 @@ void MediaPlayer2Player::audioPositionChanged()
 
 void MediaPlayer2Player::audioDurationChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::audioDurationChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::audioDurationChanged()";
     // We reset all metadata in case the audioDuration changed
     // This is done because duration is not yet available when setEntry is
     // called (this is before the QMediaPlayer has read the new track
     if (m_audioPlayer) {
-        qCDebug(Mpris2Log) << "Signal change of audio duration through MPRIS2" << m_audioPlayer->duration();
+        qCDebug(PLASMATUBE_MPRIS2) << "Signal change of audio duration through MPRIS2" << m_audioPlayer->duration();
         if (m_audioPlayer->currentVideo() != nullptr) {
             m_metadata = getMetadataOfCurrentTrack();
             signalPropertiesChange(QStringLiteral("Metadata"), Metadata());
@@ -294,43 +294,43 @@ void MediaPlayer2Player::audioDurationChanged()
 
 void MediaPlayer2Player::playerVolumeChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerVolumeChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerVolumeChanged()";
     // TODO: app volume not implemented
 }
 
 void MediaPlayer2Player::playerCanPlayChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerCanPlayChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerCanPlayChanged()";
     signalPropertiesChange(QStringLiteral("CanPlay"), CanPlay());
 }
 
 void MediaPlayer2Player::playerCanPauseChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerCanPauseChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerCanPauseChanged()";
     signalPropertiesChange(QStringLiteral("CanPause"), CanPause());
 }
 
 void MediaPlayer2Player::playerCanGoNextChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerCanGoNextChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerCanGoNextChanged()";
     signalPropertiesChange(QStringLiteral("CanGoNext"), CanGoNext());
 }
 
 void MediaPlayer2Player::playerCanGoPreviousChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerCanGoPreviousChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerCanGoPreviousChanged()";
     signalPropertiesChange(QStringLiteral("CanGoPrevious"), CanGoNext());
 }
 
 void MediaPlayer2Player::playerCanSeekChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerCanSeekChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerCanSeekChanged()";
     signalPropertiesChange(QStringLiteral("CanSeek"), CanSeek());
 }
 
 void MediaPlayer2Player::playerMetaDataChanged()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::playerMetaDataChanged()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::playerMetaDataChanged()";
     m_metadata = getMetadataOfCurrentTrack();
     signalPropertiesChange(QStringLiteral("Metadata"), Metadata());
 }
@@ -341,7 +341,7 @@ void MediaPlayer2Player::setSource()
     if (video == nullptr)
         return;
 
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::setSource(" << video->videoId() << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::setSource(" << video->videoId() << ")";
 
     if (m_audioPlayer) {
         int queuenr = 0; // TODO: figure out smart way to handle this
@@ -356,7 +356,7 @@ void MediaPlayer2Player::setSource()
 
 QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::getMetadataOfCurrentTrack()";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::getMetadataOfCurrentTrack()";
     auto result = QVariantMap();
 
     if (m_currentTrackId.isEmpty()) {
@@ -385,14 +385,14 @@ QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
 
 void MediaPlayer2Player::setPropertyPosition(int newPositionInMs)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::setPropertyPosition(" << newPositionInMs << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::setPropertyPosition(" << newPositionInMs << ")";
     // only needed for progressbar on taskbar (?)
     m_position = qlonglong(newPositionInMs) * 1000000;
 }
 
 void MediaPlayer2Player::signalPropertiesChange(const QString &property, const QVariant &value)
 {
-    qCDebug(Mpris2Log) << "MediaPlayer2Player::signalPropertiesChange(" << property << value << ")";
+    qCDebug(PLASMATUBE_MPRIS2) << "MediaPlayer2Player::signalPropertiesChange(" << property << value << ")";
     // qDebug() << "mpris signal property change" << property << value;
     QVariantMap properties;
     properties[property] = value;
